@@ -6,8 +6,8 @@ use clap::{ArgEnum, Parser};
 use itertools::iproduct;
 use mediatype::{
     media_type,
-    names::{CHARSET, OCTET_STREAM, PLAIN, TEXT},
-    MediaType, Value, WriteParams,
+    names::{CHARSET, PLAIN, TEXT},
+    Value, WriteParams,
 };
 use std::io::Read;
 use yozuk_helper_english::normalized_eq;
@@ -152,7 +152,12 @@ impl Translator for Base64Translator {
 pub struct Base64Command;
 
 impl Command for Base64Command {
-    fn run(&self, args: CommandArgs, streams: &mut [InputStream]) -> Result<Output, CommandError> {
+    fn run(
+        &self,
+        args: CommandArgs,
+        streams: &mut [InputStream],
+        _i18n: &I18n,
+    ) -> Result<Output, CommandError> {
         let streams = streams.iter_mut().map(|stream| {
             stream
                 .bytes()
@@ -162,53 +167,53 @@ impl Command for Base64Command {
         let options = Options::try_parse_from(args.args)?;
         match options.mode {
             Mode::Decode => {
-                let mut sections = vec![Section::new(
-                    "Decoding Base64 string".to_string(),
-                    media_type!(TEXT / PLAIN),
-                )
-                .kind(SectionKind::Comment)];
+                let mut blocks = vec![Block::Comment(
+                    block::Comment::new().set_text("Decoding Base64 string"),
+                )];
 
-                sections.append(
+                blocks.append(
                     &mut args
                         .data
                         .into_iter()
                         .chain(streams)
                         .filter_map(|data| base64::decode(&data).ok())
                         .map(|data| {
-                            let media_type = tree_magic::from_u8(&data);
                             let mut encdetector = EncodingDetector::new();
                             encdetector.feed(&data, true);
+                            let (enc, likely) = encdetector.guess_assess(None, true);
 
-                            let mut media_type = MediaType::parse(&media_type).unwrap();
-                            if media_type.ty == TEXT {
-                                let enc = encdetector.guess(None, true);
+                            let mut media_type = media_type!(APPLICATION / OCTET_STREAM);
+                            if likely {
+                                media_type.ty = TEXT;
+                                media_type.subty = PLAIN;
                                 media_type.set_param(CHARSET, Value::new(enc.name()).unwrap());
-                            } else if media_type.subty == OCTET_STREAM {
-                                let (enc, likely) = encdetector.guess_assess(None, true);
-                                if likely {
-                                    media_type.ty = TEXT;
-                                    media_type.subty = PLAIN;
-                                    media_type.set_param(CHARSET, Value::new(enc.name()).unwrap());
-                                }
                             }
 
-                            Section::new(data, media_type)
+                            Block::Data(
+                                block::Data::new().set_data(data).set_media_type(media_type),
+                            )
                         })
                         .collect(),
                 );
 
                 Ok(Output {
-                    module: "Base64 Decoder".into(),
-                    sections,
+                    title: "Base64 Decoder".into(),
+                    blocks,
                 })
             }
             Mode::Encode => Ok(Output {
-                module: "Base64 Encoder".into(),
-                sections: args
+                title: "Base64 Encoder".into(),
+                blocks: args
                     .data
                     .into_iter()
                     .chain(streams)
-                    .map(|data| Section::new(base64::encode(data), media_type!(TEXT / PLAIN)))
+                    .map(|data| {
+                        Block::Data(
+                            block::Data::new()
+                                .set_data(base64::encode(data))
+                                .set_media_type(media_type!(TEXT / PLAIN)),
+                        )
+                    })
                     .collect(),
             }),
         }
