@@ -1,16 +1,15 @@
 #![forbid(unsafe_code)]
 #![deny(clippy::all)]
 
-use mediatype::{media_type, MediaType};
 use pest::iterators::{Pair, Pairs};
 use pest::prec_climber::*;
 use pest::Parser;
 use rand::{rngs::SmallRng, Rng, SeedableRng};
 use serde_derive::Deserialize;
-use std::collections::VecDeque;
 use std::iter;
 use thiserror::Error;
 use yozuk_helper_english::normalized_eq;
+use yozuk_helper_preprocessor::{TokenMerger, TokenParser};
 use yozuk_sdk::prelude::*;
 
 pub const ENTRY: SkillEntry = SkillEntry {
@@ -19,7 +18,7 @@ pub const ENTRY: SkillEntry = SkillEntry {
     init: |_, config| {
         Skill::builder()
             .add_corpus(DiceCorpus)
-            .add_preprocessor(DicePreprocessor)
+            .add_preprocessor(TokenMerger::new(DiceTokenParser))
             .add_translator(DiceTranslator)
             .set_command(DiceCommand(config.get()))
             .build()
@@ -35,6 +34,7 @@ impl Corpus for DiceCorpus {
     fn training_data(&self) -> Vec<Vec<Token>> {
         vec![
             tk!(["dice"; "command:dice"]),
+            tk!(["🎲"; "command:dice"]),
             tk!([
                 "roll",
                 "die"; "command:dice"
@@ -52,39 +52,26 @@ impl Corpus for DiceCorpus {
     }
 }
 
-#[derive(Debug)]
-struct DicePreprocessor;
+struct DiceTokenParser;
 
-impl Preprocessor for DicePreprocessor {
-    fn preprocess(&self, input: Vec<Token>) -> Vec<Token> {
-        let mut output = Vec::new();
-        let mut tokens = input.into_iter().collect::<VecDeque<_>>();
-        while !tokens.is_empty() {
-            for i in 1..=tokens.len() {
-                let len = tokens.len() + 1 - i;
-                let exp = tokens
-                    .iter()
-                    .take(len)
-                    .map(|token| token.as_utf8())
-                    .collect::<Vec<_>>();
-                let exp = exp.join("");
-                let is_exp = match DiceParser::parse(Rule::calculation, &exp) {
-                    Ok(pairs) => pairs.flatten().any(|pair| pair.as_rule() == Rule::dice),
-                    _ => false,
-                };
-                if is_exp {
-                    for _ in 0..len {
-                        tokens.pop_front();
-                    }
-                    output.push(tk!(exp, "text/vnd.yozuk.dice"));
-                    break;
-                }
-            }
-            if let Some(front) = tokens.pop_front() {
-                output.push(front);
+impl TokenParser for DiceTokenParser {
+    fn parse(&self, tokens: &[Token]) -> Option<Token> {
+        let exp = tokens
+            .iter()
+            .map(|token| token.as_utf8())
+            .collect::<Vec<_>>()
+            .join("");
+        match DiceParser::parse(Rule::calculation, &exp) {
+            Ok(pairs)
+                if pairs
+                    .clone()
+                    .flatten()
+                    .any(|pair| pair.as_rule() == Rule::dice) =>
+            {
+                Some(tk!(exp, "text/vnd.yozuk.dice"))
             }
+            _ => None,
         }
-        output
     }
 }
 
@@ -167,10 +154,12 @@ impl Value {
 impl ToString for Value {
     fn to_string(&self) -> String {
         match self {
-            Self::Dice(dice) if dice.len() == 1 => self.sum().to_string(),
+            Self::Dice(dice) if dice.len() == 1 => {
+                format!("🎲 {}", self.sum())
+            }
             Self::Dice(dice) => {
                 let history = dice.iter().map(ToString::to_string).collect::<Vec<_>>();
-                format!("{} ({})", self.sum(), history.join(" "))
+                format!("🎲 {}\nsum: {}", history.join(" "), self.sum())
             }
             Self::Sum(sum) => sum.to_string(),
         }
@@ -203,7 +192,7 @@ impl Translator for DiceTranslator {
             .collect::<Vec<_>>();
 
         if let [dice] = commands[..] {
-            if normalized_eq(dice.as_utf8(), &["dice", "die"], 0) {
+            if normalized_eq(dice.as_utf8(), &["dice", "die", "🎲"], 0) {
                 return Some(CommandArgs::new().add_args([format!("{}d6", count)]));
             }
         }
@@ -229,17 +218,29 @@ impl Translator for DiceTranslator {
 pub struct DiceCommand(DiceConfig);
 
 impl Command for DiceCommand {
-    fn run(&self, args: CommandArgs, _streams: &mut [InputStream]) -> Result<Output, CommandError> {
+    fn run(
+        &self,
+        args: CommandArgs,
+        _streams: &mut [InputStream],
+        _i18n: &I18n,
+    ) -> Result<Output, CommandError> {
         let rule = DiceParser::parse(Rule::calculation, &args.args[1])?;
         Ok(eval(rule, &self.0)
             .map(|result| Output {
-                module: "Dice".into(),
-                sections: vec![Section::new(result.to_string(), media_type!(TEXT / PLAIN))],
+                title: "Dice".into(),
+                blocks: vec![Block::Data(
+                    block::Data::new()
+                        .set_data(result.to_string())
+                        .set_media_type(media_type!(TEXT / PLAIN)),
+                )],
             })
             .map_err(|err| Output {
-                module: "Dice".into(),
-                sections: vec![Section::new(format!("{}", err), media_type!(TEXT / PLAIN))
-                    .kind(SectionKind::Comment)],
+                title: "Dice".into(),
+                blocks: vec![Block::Data(
+                    block::Data::new()
+                        .set_data(format!("{}", err))
+                        .set_media_type(media_type!(TEXT / PLAIN)),
+                )],
             })?)
     }
 }
