@@ -4,7 +4,6 @@
 use clap::Parser;
 use lipsum::lipsum;
 use lipsum::MarkovChain;
-use mediatype::media_type;
 use serde_derive::Deserialize;
 use yozuk_helper_english::normalized_eq;
 use yozuk_sdk::prelude::*;
@@ -157,7 +156,12 @@ const MAX_COUNT: usize = 300;
 pub struct LipsumCommand(LipsumConfig);
 
 impl Command for LipsumCommand {
-    fn run(&self, args: CommandArgs, _streams: &mut [InputStream]) -> Result<Output, CommandError> {
+    fn run(
+        &self,
+        args: CommandArgs,
+        _streams: &mut [InputStream],
+        _i18n: &I18n,
+    ) -> Result<Output, CommandError> {
         let chain = self.0.custom_text.as_ref().map(|text| {
             let mut chain = MarkovChain::new();
             chain.learn(text);
@@ -167,28 +171,24 @@ impl Command for LipsumCommand {
         let args = Args::try_parse_from(args.args)?;
         if args.n > MAX_COUNT {
             return Err(Output {
-                module: "Lorem ipsum".into(),
-                sections: vec![Section::new(
-                    format!(
-                        "Too large number of the requested words (Limit: {}).",
-                        MAX_COUNT
-                    ),
-                    media_type!(TEXT / PLAIN),
-                )
-                .kind(SectionKind::Comment)],
+                title: "Lorem ipsum".into(),
+                blocks: vec![Block::Comment(block::Comment::new().set_text(format!(
+                    "Too large number of the requested words (Limit: {}).",
+                    MAX_COUNT
+                )))],
             }
             .into());
         }
         Ok(Output {
-            sections: vec![Section::new(
-                if let Some(chain) = chain {
-                    chain.generate(args.n)
-                } else {
-                    lipsum(args.n)
-                },
-                media_type!(TEXT / PLAIN),
-            )
-            .kind(SectionKind::Value)],
+            blocks: vec![Block::Comment(
+                block::Comment::new()
+                    .set_text(if let Some(chain) = chain {
+                        chain.generate(args.n)
+                    } else {
+                        lipsum(args.n)
+                    })
+                    .set_media_type(media_type!(TEXT / PLAIN)),
+            )],
             ..Default::default()
         })
     }
